# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRaftAutopilotStateResult',
    'AwaitableGetRaftAutopilotStateResult',
    'get_raft_autopilot_state',
    'get_raft_autopilot_state_output',
]

@pulumi.output_type
class GetRaftAutopilotStateResult:
    """
    A collection of values returned by getRaftAutopilotState.
    """
    def __init__(__self__, failure_tolerance=None, healthy=None, id=None, leader=None, namespace=None, optimistic_failure_tolerance=None, redundancy_zones=None, redundancy_zones_json=None, servers=None, servers_json=None, upgrade_info=None, upgrade_info_json=None, voters=None):
        if failure_tolerance and not isinstance(failure_tolerance, int):
            raise TypeError("Expected argument 'failure_tolerance' to be a int")
        pulumi.set(__self__, "failure_tolerance", failure_tolerance)
        if healthy and not isinstance(healthy, bool):
            raise TypeError("Expected argument 'healthy' to be a bool")
        pulumi.set(__self__, "healthy", healthy)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if leader and not isinstance(leader, str):
            raise TypeError("Expected argument 'leader' to be a str")
        pulumi.set(__self__, "leader", leader)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if optimistic_failure_tolerance and not isinstance(optimistic_failure_tolerance, int):
            raise TypeError("Expected argument 'optimistic_failure_tolerance' to be a int")
        pulumi.set(__self__, "optimistic_failure_tolerance", optimistic_failure_tolerance)
        if redundancy_zones and not isinstance(redundancy_zones, dict):
            raise TypeError("Expected argument 'redundancy_zones' to be a dict")
        pulumi.set(__self__, "redundancy_zones", redundancy_zones)
        if redundancy_zones_json and not isinstance(redundancy_zones_json, str):
            raise TypeError("Expected argument 'redundancy_zones_json' to be a str")
        pulumi.set(__self__, "redundancy_zones_json", redundancy_zones_json)
        if servers and not isinstance(servers, dict):
            raise TypeError("Expected argument 'servers' to be a dict")
        pulumi.set(__self__, "servers", servers)
        if servers_json and not isinstance(servers_json, str):
            raise TypeError("Expected argument 'servers_json' to be a str")
        pulumi.set(__self__, "servers_json", servers_json)
        if upgrade_info and not isinstance(upgrade_info, dict):
            raise TypeError("Expected argument 'upgrade_info' to be a dict")
        pulumi.set(__self__, "upgrade_info", upgrade_info)
        if upgrade_info_json and not isinstance(upgrade_info_json, str):
            raise TypeError("Expected argument 'upgrade_info_json' to be a str")
        pulumi.set(__self__, "upgrade_info_json", upgrade_info_json)
        if voters and not isinstance(voters, list):
            raise TypeError("Expected argument 'voters' to be a list")
        pulumi.set(__self__, "voters", voters)

    @_builtins.property
    @pulumi.getter(name="failureTolerance")
    def failure_tolerance(self) -> _builtins.int:
        """
        How many nodes could fail before the cluster becomes unhealthy.
        """
        return pulumi.get(self, "failure_tolerance")

    @_builtins.property
    @pulumi.getter
    def healthy(self) -> _builtins.bool:
        """
        Cluster health status.
        """
        return pulumi.get(self, "healthy")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def leader(self) -> _builtins.str:
        """
        The current leader of Vault.
        """
        return pulumi.get(self, "leader")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="optimisticFailureTolerance")
    def optimistic_failure_tolerance(self) -> _builtins.int:
        """
        The cluster-level optimistic failure tolerance.
        """
        return pulumi.get(self, "optimistic_failure_tolerance")

    @_builtins.property
    @pulumi.getter(name="redundancyZones")
    def redundancy_zones(self) -> Mapping[str, _builtins.str]:
        """
        Additional output related to redundancy zones stored as a serialized map of strings.
        """
        return pulumi.get(self, "redundancy_zones")

    @_builtins.property
    @pulumi.getter(name="redundancyZonesJson")
    def redundancy_zones_json(self) -> _builtins.str:
        """
        Additional output related to redundancy zones.
        """
        return pulumi.get(self, "redundancy_zones_json")

    @_builtins.property
    @pulumi.getter
    def servers(self) -> Mapping[str, _builtins.str]:
        """
        Additionaly output related to servers in the cluster stored as a serialized map of strings.
        """
        return pulumi.get(self, "servers")

    @_builtins.property
    @pulumi.getter(name="serversJson")
    def servers_json(self) -> _builtins.str:
        """
        Additionaly output related to servers in the cluster.
        """
        return pulumi.get(self, "servers_json")

    @_builtins.property
    @pulumi.getter(name="upgradeInfo")
    def upgrade_info(self) -> Mapping[str, _builtins.str]:
        """
        Additional output related to upgrade information stored as a serialized map of strings.
        """
        return pulumi.get(self, "upgrade_info")

    @_builtins.property
    @pulumi.getter(name="upgradeInfoJson")
    def upgrade_info_json(self) -> _builtins.str:
        """
        Additional output related to upgrade information.
        """
        return pulumi.get(self, "upgrade_info_json")

    @_builtins.property
    @pulumi.getter
    def voters(self) -> Sequence[_builtins.str]:
        """
        The voters in the Vault cluster.
        """
        return pulumi.get(self, "voters")


class AwaitableGetRaftAutopilotStateResult(GetRaftAutopilotStateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRaftAutopilotStateResult(
            failure_tolerance=self.failure_tolerance,
            healthy=self.healthy,
            id=self.id,
            leader=self.leader,
            namespace=self.namespace,
            optimistic_failure_tolerance=self.optimistic_failure_tolerance,
            redundancy_zones=self.redundancy_zones,
            redundancy_zones_json=self.redundancy_zones_json,
            servers=self.servers,
            servers_json=self.servers_json,
            upgrade_info=self.upgrade_info,
            upgrade_info_json=self.upgrade_info_json,
            voters=self.voters)


def get_raft_autopilot_state(namespace: Optional[_builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRaftAutopilotStateResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    main = vault.get_raft_autopilot_state()
    pulumi.export("failure-tolerance", main.failure_tolerance)
    ```


    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:index/getRaftAutopilotState:getRaftAutopilotState', __args__, opts=opts, typ=GetRaftAutopilotStateResult).value

    return AwaitableGetRaftAutopilotStateResult(
        failure_tolerance=pulumi.get(__ret__, 'failure_tolerance'),
        healthy=pulumi.get(__ret__, 'healthy'),
        id=pulumi.get(__ret__, 'id'),
        leader=pulumi.get(__ret__, 'leader'),
        namespace=pulumi.get(__ret__, 'namespace'),
        optimistic_failure_tolerance=pulumi.get(__ret__, 'optimistic_failure_tolerance'),
        redundancy_zones=pulumi.get(__ret__, 'redundancy_zones'),
        redundancy_zones_json=pulumi.get(__ret__, 'redundancy_zones_json'),
        servers=pulumi.get(__ret__, 'servers'),
        servers_json=pulumi.get(__ret__, 'servers_json'),
        upgrade_info=pulumi.get(__ret__, 'upgrade_info'),
        upgrade_info_json=pulumi.get(__ret__, 'upgrade_info_json'),
        voters=pulumi.get(__ret__, 'voters'))
def get_raft_autopilot_state_output(namespace: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRaftAutopilotStateResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    main = vault.get_raft_autopilot_state()
    pulumi.export("failure-tolerance", main.failure_tolerance)
    ```


    :param _builtins.str namespace: The namespace of the target resource.
           The value should not contain leading or trailing forward slashes.
           The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
           *Available only for Vault Enterprise*.
    """
    __args__ = dict()
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vault:index/getRaftAutopilotState:getRaftAutopilotState', __args__, opts=opts, typ=GetRaftAutopilotStateResult)
    return __ret__.apply(lambda __response__: GetRaftAutopilotStateResult(
        failure_tolerance=pulumi.get(__response__, 'failure_tolerance'),
        healthy=pulumi.get(__response__, 'healthy'),
        id=pulumi.get(__response__, 'id'),
        leader=pulumi.get(__response__, 'leader'),
        namespace=pulumi.get(__response__, 'namespace'),
        optimistic_failure_tolerance=pulumi.get(__response__, 'optimistic_failure_tolerance'),
        redundancy_zones=pulumi.get(__response__, 'redundancy_zones'),
        redundancy_zones_json=pulumi.get(__response__, 'redundancy_zones_json'),
        servers=pulumi.get(__response__, 'servers'),
        servers_json=pulumi.get(__response__, 'servers_json'),
        upgrade_info=pulumi.get(__response__, 'upgrade_info'),
        upgrade_info_json=pulumi.get(__response__, 'upgrade_info_json'),
        voters=pulumi.get(__response__, 'voters')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BackendConfigAutoTidyArgs', 'BackendConfigAutoTidy']

@pulumi.input_type
class BackendConfigAutoTidyArgs:
    def __init__(__self__, *,
                 backend: pulumi.Input[_builtins.str],
                 enabled: pulumi.Input[_builtins.bool],
                 acme_account_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 interval_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 maintain_stored_certificate_counts: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 min_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 pause_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 publish_stored_certificate_count_metrics: Optional[pulumi.Input[_builtins.bool]] = None,
                 revocation_queue_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 tidy_acme: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cert_metadata: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cert_store: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cmpv2_nonce_store: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cross_cluster_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_expired_issuers: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_move_legacy_ca_bundle: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revocation_queue: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revoked_cert_issuer_associations: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a BackendConfigAutoTidy resource.
        :param pulumi.Input[_builtins.str] backend: The path to the PKI secret backend to
               read the configuration from, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether automatic tidy is enabled or not.
        :param pulumi.Input[_builtins.str] acme_account_safety_buffer: The amount of time that must pass after creation that an account with no orders is marked revoked, and the amount of time after being marked revoked or deactivated.
        :param pulumi.Input[_builtins.str] interval_duration: Interval at which to run an auto-tidy operation. This is the time
               between tidy invocations (after one finishes to the start of the next).
        :param pulumi.Input[_builtins.str] issuer_safety_buffer: The amount of extra time that must have passed beyond issuer's
               expiration before it is removed from the backend storage.
        :param pulumi.Input[_builtins.bool] maintain_stored_certificate_counts: This configures whether stored certificate are
               counted upon initialization of the backend, and whether during normal operation, a running count
               of certificates stored is maintained.
        :param pulumi.Input[_builtins.str] max_startup_backoff_duration: The maximum amount of time auto-tidy will be delayed
               after startup.
        :param pulumi.Input[_builtins.str] min_startup_backoff_duration: The minimum amount of time auto-tidy will be delayed
               after startup.
        :param pulumi.Input[_builtins.str] namespace: The namespace of the target resource.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] pause_duration: The amount of time to wait between processing certificates.
        :param pulumi.Input[_builtins.bool] publish_stored_certificate_count_metrics: This configures whether the stored
               certificate count is published to the metrics consumer.
        :param pulumi.Input[_builtins.str] revocation_queue_safety_buffer: The amount of time that must pass from the
               cross-cluster revocation request being initiated to when it will be slated for removal.
        :param pulumi.Input[_builtins.str] safety_buffer: The amount of extra time that must have passed beyond certificate
               expiration before it is removed from the backend storage and/or revocation list.
        :param pulumi.Input[_builtins.bool] tidy_acme: Set to true to enable tidying ACME accounts, orders and authorizations.
        :param pulumi.Input[_builtins.bool] tidy_cert_metadata: Set to true to enable tidying up certificate metadata.
        :param pulumi.Input[_builtins.bool] tidy_cert_store: Set to true to enable tidying up the certificate store
        :param pulumi.Input[_builtins.bool] tidy_cmpv2_nonce_store: Set to true to enable tidying up the CMPv2 nonce store.
        :param pulumi.Input[_builtins.bool] tidy_cross_cluster_revoked_certs: Set to true to enable tidying up the cross-cluster
               revoked certificate store.
        :param pulumi.Input[_builtins.bool] tidy_expired_issuers: Set to true to automatically remove expired issuers past the
               `issuer_safety_buffer`. No keys will be removed as part of this operation.
        :param pulumi.Input[_builtins.bool] tidy_move_legacy_ca_bundle: Set to true to move the legacy `ca_bundle` from
               `/config/ca_bundle` to `/config/ca_bundle.bak`.
        :param pulumi.Input[_builtins.bool] tidy_revocation_queue: Set to true to remove stale revocation queue entries that
               haven't been confirmed by any active cluster.
        :param pulumi.Input[_builtins.bool] tidy_revoked_cert_issuer_associations: Set to true to validate issuer associations
               on revocation entries. This helps increase the performance of CRL building and OCSP responses.
        :param pulumi.Input[_builtins.bool] tidy_revoked_certs: Set to true to remove all invalid and expired certificates from
               storage. A revoked storage entry is considered invalid if the entry is empty, or the value within
               the entry is empty. If a certificate is removed due to expiry, the entry will also be removed from
               the CRL, and the CRL will be rotated.
        """
        pulumi.set(__self__, "backend", backend)
        pulumi.set(__self__, "enabled", enabled)
        if acme_account_safety_buffer is not None:
            pulumi.set(__self__, "acme_account_safety_buffer", acme_account_safety_buffer)
        if interval_duration is not None:
            pulumi.set(__self__, "interval_duration", interval_duration)
        if issuer_safety_buffer is not None:
            pulumi.set(__self__, "issuer_safety_buffer", issuer_safety_buffer)
        if maintain_stored_certificate_counts is not None:
            pulumi.set(__self__, "maintain_stored_certificate_counts", maintain_stored_certificate_counts)
        if max_startup_backoff_duration is not None:
            pulumi.set(__self__, "max_startup_backoff_duration", max_startup_backoff_duration)
        if min_startup_backoff_duration is not None:
            pulumi.set(__self__, "min_startup_backoff_duration", min_startup_backoff_duration)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if pause_duration is not None:
            pulumi.set(__self__, "pause_duration", pause_duration)
        if publish_stored_certificate_count_metrics is not None:
            pulumi.set(__self__, "publish_stored_certificate_count_metrics", publish_stored_certificate_count_metrics)
        if revocation_queue_safety_buffer is not None:
            pulumi.set(__self__, "revocation_queue_safety_buffer", revocation_queue_safety_buffer)
        if safety_buffer is not None:
            pulumi.set(__self__, "safety_buffer", safety_buffer)
        if tidy_acme is not None:
            pulumi.set(__self__, "tidy_acme", tidy_acme)
        if tidy_cert_metadata is not None:
            pulumi.set(__self__, "tidy_cert_metadata", tidy_cert_metadata)
        if tidy_cert_store is not None:
            pulumi.set(__self__, "tidy_cert_store", tidy_cert_store)
        if tidy_cmpv2_nonce_store is not None:
            pulumi.set(__self__, "tidy_cmpv2_nonce_store", tidy_cmpv2_nonce_store)
        if tidy_cross_cluster_revoked_certs is not None:
            pulumi.set(__self__, "tidy_cross_cluster_revoked_certs", tidy_cross_cluster_revoked_certs)
        if tidy_expired_issuers is not None:
            pulumi.set(__self__, "tidy_expired_issuers", tidy_expired_issuers)
        if tidy_move_legacy_ca_bundle is not None:
            pulumi.set(__self__, "tidy_move_legacy_ca_bundle", tidy_move_legacy_ca_bundle)
        if tidy_revocation_queue is not None:
            pulumi.set(__self__, "tidy_revocation_queue", tidy_revocation_queue)
        if tidy_revoked_cert_issuer_associations is not None:
            pulumi.set(__self__, "tidy_revoked_cert_issuer_associations", tidy_revoked_cert_issuer_associations)
        if tidy_revoked_certs is not None:
            pulumi.set(__self__, "tidy_revoked_certs", tidy_revoked_certs)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> pulumi.Input[_builtins.str]:
        """
        The path to the PKI secret backend to
        read the configuration from, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Specifies whether automatic tidy is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="acmeAccountSafetyBuffer")
    def acme_account_safety_buffer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of time that must pass after creation that an account with no orders is marked revoked, and the amount of time after being marked revoked or deactivated.
        """
        return pulumi.get(self, "acme_account_safety_buffer")

    @acme_account_safety_buffer.setter
    def acme_account_safety_buffer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "acme_account_safety_buffer", value)

    @_builtins.property
    @pulumi.getter(name="intervalDuration")
    def interval_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Interval at which to run an auto-tidy operation. This is the time
        between tidy invocations (after one finishes to the start of the next).
        """
        return pulumi.get(self, "interval_duration")

    @interval_duration.setter
    def interval_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "interval_duration", value)

    @_builtins.property
    @pulumi.getter(name="issuerSafetyBuffer")
    def issuer_safety_buffer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of extra time that must have passed beyond issuer's
        expiration before it is removed from the backend storage.
        """
        return pulumi.get(self, "issuer_safety_buffer")

    @issuer_safety_buffer.setter
    def issuer_safety_buffer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "issuer_safety_buffer", value)

    @_builtins.property
    @pulumi.getter(name="maintainStoredCertificateCounts")
    def maintain_stored_certificate_counts(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        This configures whether stored certificate are
        counted upon initialization of the backend, and whether during normal operation, a running count
        of certificates stored is maintained.
        """
        return pulumi.get(self, "maintain_stored_certificate_counts")

    @maintain_stored_certificate_counts.setter
    def maintain_stored_certificate_counts(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "maintain_stored_certificate_counts", value)

    @_builtins.property
    @pulumi.getter(name="maxStartupBackoffDuration")
    def max_startup_backoff_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The maximum amount of time auto-tidy will be delayed
        after startup.
        """
        return pulumi.get(self, "max_startup_backoff_duration")

    @max_startup_backoff_duration.setter
    def max_startup_backoff_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "max_startup_backoff_duration", value)

    @_builtins.property
    @pulumi.getter(name="minStartupBackoffDuration")
    def min_startup_backoff_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The minimum amount of time auto-tidy will be delayed
        after startup.
        """
        return pulumi.get(self, "min_startup_backoff_duration")

    @min_startup_backoff_duration.setter
    def min_startup_backoff_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "min_startup_backoff_duration", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace of the target resource.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="pauseDuration")
    def pause_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of time to wait between processing certificates.
        """
        return pulumi.get(self, "pause_duration")

    @pause_duration.setter
    def pause_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pause_duration", value)

    @_builtins.property
    @pulumi.getter(name="publishStoredCertificateCountMetrics")
    def publish_stored_certificate_count_metrics(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        This configures whether the stored
        certificate count is published to the metrics consumer.
        """
        return pulumi.get(self, "publish_stored_certificate_count_metrics")

    @publish_stored_certificate_count_metrics.setter
    def publish_stored_certificate_count_metrics(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "publish_stored_certificate_count_metrics", value)

    @_builtins.property
    @pulumi.getter(name="revocationQueueSafetyBuffer")
    def revocation_queue_safety_buffer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of time that must pass from the
        cross-cluster revocation request being initiated to when it will be slated for removal.
        """
        return pulumi.get(self, "revocation_queue_safety_buffer")

    @revocation_queue_safety_buffer.setter
    def revocation_queue_safety_buffer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "revocation_queue_safety_buffer", value)

    @_builtins.property
    @pulumi.getter(name="safetyBuffer")
    def safety_buffer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of extra time that must have passed beyond certificate
        expiration before it is removed from the backend storage and/or revocation list.
        """
        return pulumi.get(self, "safety_buffer")

    @safety_buffer.setter
    def safety_buffer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "safety_buffer", value)

    @_builtins.property
    @pulumi.getter(name="tidyAcme")
    def tidy_acme(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying ACME accounts, orders and authorizations.
        """
        return pulumi.get(self, "tidy_acme")

    @tidy_acme.setter
    def tidy_acme(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_acme", value)

    @_builtins.property
    @pulumi.getter(name="tidyCertMetadata")
    def tidy_cert_metadata(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying up certificate metadata.
        """
        return pulumi.get(self, "tidy_cert_metadata")

    @tidy_cert_metadata.setter
    def tidy_cert_metadata(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_cert_metadata", value)

    @_builtins.property
    @pulumi.getter(name="tidyCertStore")
    def tidy_cert_store(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying up the certificate store
        """
        return pulumi.get(self, "tidy_cert_store")

    @tidy_cert_store.setter
    def tidy_cert_store(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_cert_store", value)

    @_builtins.property
    @pulumi.getter(name="tidyCmpv2NonceStore")
    def tidy_cmpv2_nonce_store(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying up the CMPv2 nonce store.
        """
        return pulumi.get(self, "tidy_cmpv2_nonce_store")

    @tidy_cmpv2_nonce_store.setter
    def tidy_cmpv2_nonce_store(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_cmpv2_nonce_store", value)

    @_builtins.property
    @pulumi.getter(name="tidyCrossClusterRevokedCerts")
    def tidy_cross_cluster_revoked_certs(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying up the cross-cluster
        revoked certificate store.
        """
        return pulumi.get(self, "tidy_cross_cluster_revoked_certs")

    @tidy_cross_cluster_revoked_certs.setter
    def tidy_cross_cluster_revoked_certs(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_cross_cluster_revoked_certs", value)

    @_builtins.property
    @pulumi.getter(name="tidyExpiredIssuers")
    def tidy_expired_issuers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to automatically remove expired issuers past the
        `issuer_safety_buffer`. No keys will be removed as part of this operation.
        """
        return pulumi.get(self, "tidy_expired_issuers")

    @tidy_expired_issuers.setter
    def tidy_expired_issuers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_expired_issuers", value)

    @_builtins.property
    @pulumi.getter(name="tidyMoveLegacyCaBundle")
    def tidy_move_legacy_ca_bundle(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to move the legacy `ca_bundle` from
        `/config/ca_bundle` to `/config/ca_bundle.bak`.
        """
        return pulumi.get(self, "tidy_move_legacy_ca_bundle")

    @tidy_move_legacy_ca_bundle.setter
    def tidy_move_legacy_ca_bundle(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_move_legacy_ca_bundle", value)

    @_builtins.property
    @pulumi.getter(name="tidyRevocationQueue")
    def tidy_revocation_queue(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to remove stale revocation queue entries that
        haven't been confirmed by any active cluster.
        """
        return pulumi.get(self, "tidy_revocation_queue")

    @tidy_revocation_queue.setter
    def tidy_revocation_queue(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_revocation_queue", value)

    @_builtins.property
    @pulumi.getter(name="tidyRevokedCertIssuerAssociations")
    def tidy_revoked_cert_issuer_associations(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to validate issuer associations
        on revocation entries. This helps increase the performance of CRL building and OCSP responses.
        """
        return pulumi.get(self, "tidy_revoked_cert_issuer_associations")

    @tidy_revoked_cert_issuer_associations.setter
    def tidy_revoked_cert_issuer_associations(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_revoked_cert_issuer_associations", value)

    @_builtins.property
    @pulumi.getter(name="tidyRevokedCerts")
    def tidy_revoked_certs(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to remove all invalid and expired certificates from
        storage. A revoked storage entry is considered invalid if the entry is empty, or the value within
        the entry is empty. If a certificate is removed due to expiry, the entry will also be removed from
        the CRL, and the CRL will be rotated.
        """
        return pulumi.get(self, "tidy_revoked_certs")

    @tidy_revoked_certs.setter
    def tidy_revoked_certs(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_revoked_certs", value)


@pulumi.input_type
class _BackendConfigAutoTidyState:
    def __init__(__self__, *,
                 acme_account_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 interval_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 maintain_stored_certificate_counts: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 min_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 pause_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 publish_stored_certificate_count_metrics: Optional[pulumi.Input[_builtins.bool]] = None,
                 revocation_queue_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 tidy_acme: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cert_metadata: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cert_store: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cmpv2_nonce_store: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cross_cluster_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_expired_issuers: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_move_legacy_ca_bundle: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revocation_queue: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revoked_cert_issuer_associations: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering BackendConfigAutoTidy resources.
        :param pulumi.Input[_builtins.str] acme_account_safety_buffer: The amount of time that must pass after creation that an account with no orders is marked revoked, and the amount of time after being marked revoked or deactivated.
        :param pulumi.Input[_builtins.str] backend: The path to the PKI secret backend to
               read the configuration from, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether automatic tidy is enabled or not.
        :param pulumi.Input[_builtins.str] interval_duration: Interval at which to run an auto-tidy operation. This is the time
               between tidy invocations (after one finishes to the start of the next).
        :param pulumi.Input[_builtins.str] issuer_safety_buffer: The amount of extra time that must have passed beyond issuer's
               expiration before it is removed from the backend storage.
        :param pulumi.Input[_builtins.bool] maintain_stored_certificate_counts: This configures whether stored certificate are
               counted upon initialization of the backend, and whether during normal operation, a running count
               of certificates stored is maintained.
        :param pulumi.Input[_builtins.str] max_startup_backoff_duration: The maximum amount of time auto-tidy will be delayed
               after startup.
        :param pulumi.Input[_builtins.str] min_startup_backoff_duration: The minimum amount of time auto-tidy will be delayed
               after startup.
        :param pulumi.Input[_builtins.str] namespace: The namespace of the target resource.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] pause_duration: The amount of time to wait between processing certificates.
        :param pulumi.Input[_builtins.bool] publish_stored_certificate_count_metrics: This configures whether the stored
               certificate count is published to the metrics consumer.
        :param pulumi.Input[_builtins.str] revocation_queue_safety_buffer: The amount of time that must pass from the
               cross-cluster revocation request being initiated to when it will be slated for removal.
        :param pulumi.Input[_builtins.str] safety_buffer: The amount of extra time that must have passed beyond certificate
               expiration before it is removed from the backend storage and/or revocation list.
        :param pulumi.Input[_builtins.bool] tidy_acme: Set to true to enable tidying ACME accounts, orders and authorizations.
        :param pulumi.Input[_builtins.bool] tidy_cert_metadata: Set to true to enable tidying up certificate metadata.
        :param pulumi.Input[_builtins.bool] tidy_cert_store: Set to true to enable tidying up the certificate store
        :param pulumi.Input[_builtins.bool] tidy_cmpv2_nonce_store: Set to true to enable tidying up the CMPv2 nonce store.
        :param pulumi.Input[_builtins.bool] tidy_cross_cluster_revoked_certs: Set to true to enable tidying up the cross-cluster
               revoked certificate store.
        :param pulumi.Input[_builtins.bool] tidy_expired_issuers: Set to true to automatically remove expired issuers past the
               `issuer_safety_buffer`. No keys will be removed as part of this operation.
        :param pulumi.Input[_builtins.bool] tidy_move_legacy_ca_bundle: Set to true to move the legacy `ca_bundle` from
               `/config/ca_bundle` to `/config/ca_bundle.bak`.
        :param pulumi.Input[_builtins.bool] tidy_revocation_queue: Set to true to remove stale revocation queue entries that
               haven't been confirmed by any active cluster.
        :param pulumi.Input[_builtins.bool] tidy_revoked_cert_issuer_associations: Set to true to validate issuer associations
               on revocation entries. This helps increase the performance of CRL building and OCSP responses.
        :param pulumi.Input[_builtins.bool] tidy_revoked_certs: Set to true to remove all invalid and expired certificates from
               storage. A revoked storage entry is considered invalid if the entry is empty, or the value within
               the entry is empty. If a certificate is removed due to expiry, the entry will also be removed from
               the CRL, and the CRL will be rotated.
        """
        if acme_account_safety_buffer is not None:
            pulumi.set(__self__, "acme_account_safety_buffer", acme_account_safety_buffer)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if interval_duration is not None:
            pulumi.set(__self__, "interval_duration", interval_duration)
        if issuer_safety_buffer is not None:
            pulumi.set(__self__, "issuer_safety_buffer", issuer_safety_buffer)
        if maintain_stored_certificate_counts is not None:
            pulumi.set(__self__, "maintain_stored_certificate_counts", maintain_stored_certificate_counts)
        if max_startup_backoff_duration is not None:
            pulumi.set(__self__, "max_startup_backoff_duration", max_startup_backoff_duration)
        if min_startup_backoff_duration is not None:
            pulumi.set(__self__, "min_startup_backoff_duration", min_startup_backoff_duration)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if pause_duration is not None:
            pulumi.set(__self__, "pause_duration", pause_duration)
        if publish_stored_certificate_count_metrics is not None:
            pulumi.set(__self__, "publish_stored_certificate_count_metrics", publish_stored_certificate_count_metrics)
        if revocation_queue_safety_buffer is not None:
            pulumi.set(__self__, "revocation_queue_safety_buffer", revocation_queue_safety_buffer)
        if safety_buffer is not None:
            pulumi.set(__self__, "safety_buffer", safety_buffer)
        if tidy_acme is not None:
            pulumi.set(__self__, "tidy_acme", tidy_acme)
        if tidy_cert_metadata is not None:
            pulumi.set(__self__, "tidy_cert_metadata", tidy_cert_metadata)
        if tidy_cert_store is not None:
            pulumi.set(__self__, "tidy_cert_store", tidy_cert_store)
        if tidy_cmpv2_nonce_store is not None:
            pulumi.set(__self__, "tidy_cmpv2_nonce_store", tidy_cmpv2_nonce_store)
        if tidy_cross_cluster_revoked_certs is not None:
            pulumi.set(__self__, "tidy_cross_cluster_revoked_certs", tidy_cross_cluster_revoked_certs)
        if tidy_expired_issuers is not None:
            pulumi.set(__self__, "tidy_expired_issuers", tidy_expired_issuers)
        if tidy_move_legacy_ca_bundle is not None:
            pulumi.set(__self__, "tidy_move_legacy_ca_bundle", tidy_move_legacy_ca_bundle)
        if tidy_revocation_queue is not None:
            pulumi.set(__self__, "tidy_revocation_queue", tidy_revocation_queue)
        if tidy_revoked_cert_issuer_associations is not None:
            pulumi.set(__self__, "tidy_revoked_cert_issuer_associations", tidy_revoked_cert_issuer_associations)
        if tidy_revoked_certs is not None:
            pulumi.set(__self__, "tidy_revoked_certs", tidy_revoked_certs)

    @_builtins.property
    @pulumi.getter(name="acmeAccountSafetyBuffer")
    def acme_account_safety_buffer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of time that must pass after creation that an account with no orders is marked revoked, and the amount of time after being marked revoked or deactivated.
        """
        return pulumi.get(self, "acme_account_safety_buffer")

    @acme_account_safety_buffer.setter
    def acme_account_safety_buffer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "acme_account_safety_buffer", value)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to the PKI secret backend to
        read the configuration from, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether automatic tidy is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="intervalDuration")
    def interval_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Interval at which to run an auto-tidy operation. This is the time
        between tidy invocations (after one finishes to the start of the next).
        """
        return pulumi.get(self, "interval_duration")

    @interval_duration.setter
    def interval_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "interval_duration", value)

    @_builtins.property
    @pulumi.getter(name="issuerSafetyBuffer")
    def issuer_safety_buffer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of extra time that must have passed beyond issuer's
        expiration before it is removed from the backend storage.
        """
        return pulumi.get(self, "issuer_safety_buffer")

    @issuer_safety_buffer.setter
    def issuer_safety_buffer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "issuer_safety_buffer", value)

    @_builtins.property
    @pulumi.getter(name="maintainStoredCertificateCounts")
    def maintain_stored_certificate_counts(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        This configures whether stored certificate are
        counted upon initialization of the backend, and whether during normal operation, a running count
        of certificates stored is maintained.
        """
        return pulumi.get(self, "maintain_stored_certificate_counts")

    @maintain_stored_certificate_counts.setter
    def maintain_stored_certificate_counts(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "maintain_stored_certificate_counts", value)

    @_builtins.property
    @pulumi.getter(name="maxStartupBackoffDuration")
    def max_startup_backoff_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The maximum amount of time auto-tidy will be delayed
        after startup.
        """
        return pulumi.get(self, "max_startup_backoff_duration")

    @max_startup_backoff_duration.setter
    def max_startup_backoff_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "max_startup_backoff_duration", value)

    @_builtins.property
    @pulumi.getter(name="minStartupBackoffDuration")
    def min_startup_backoff_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The minimum amount of time auto-tidy will be delayed
        after startup.
        """
        return pulumi.get(self, "min_startup_backoff_duration")

    @min_startup_backoff_duration.setter
    def min_startup_backoff_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "min_startup_backoff_duration", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace of the target resource.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="pauseDuration")
    def pause_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of time to wait between processing certificates.
        """
        return pulumi.get(self, "pause_duration")

    @pause_duration.setter
    def pause_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pause_duration", value)

    @_builtins.property
    @pulumi.getter(name="publishStoredCertificateCountMetrics")
    def publish_stored_certificate_count_metrics(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        This configures whether the stored
        certificate count is published to the metrics consumer.
        """
        return pulumi.get(self, "publish_stored_certificate_count_metrics")

    @publish_stored_certificate_count_metrics.setter
    def publish_stored_certificate_count_metrics(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "publish_stored_certificate_count_metrics", value)

    @_builtins.property
    @pulumi.getter(name="revocationQueueSafetyBuffer")
    def revocation_queue_safety_buffer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of time that must pass from the
        cross-cluster revocation request being initiated to when it will be slated for removal.
        """
        return pulumi.get(self, "revocation_queue_safety_buffer")

    @revocation_queue_safety_buffer.setter
    def revocation_queue_safety_buffer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "revocation_queue_safety_buffer", value)

    @_builtins.property
    @pulumi.getter(name="safetyBuffer")
    def safety_buffer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The amount of extra time that must have passed beyond certificate
        expiration before it is removed from the backend storage and/or revocation list.
        """
        return pulumi.get(self, "safety_buffer")

    @safety_buffer.setter
    def safety_buffer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "safety_buffer", value)

    @_builtins.property
    @pulumi.getter(name="tidyAcme")
    def tidy_acme(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying ACME accounts, orders and authorizations.
        """
        return pulumi.get(self, "tidy_acme")

    @tidy_acme.setter
    def tidy_acme(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_acme", value)

    @_builtins.property
    @pulumi.getter(name="tidyCertMetadata")
    def tidy_cert_metadata(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying up certificate metadata.
        """
        return pulumi.get(self, "tidy_cert_metadata")

    @tidy_cert_metadata.setter
    def tidy_cert_metadata(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_cert_metadata", value)

    @_builtins.property
    @pulumi.getter(name="tidyCertStore")
    def tidy_cert_store(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying up the certificate store
        """
        return pulumi.get(self, "tidy_cert_store")

    @tidy_cert_store.setter
    def tidy_cert_store(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_cert_store", value)

    @_builtins.property
    @pulumi.getter(name="tidyCmpv2NonceStore")
    def tidy_cmpv2_nonce_store(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying up the CMPv2 nonce store.
        """
        return pulumi.get(self, "tidy_cmpv2_nonce_store")

    @tidy_cmpv2_nonce_store.setter
    def tidy_cmpv2_nonce_store(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_cmpv2_nonce_store", value)

    @_builtins.property
    @pulumi.getter(name="tidyCrossClusterRevokedCerts")
    def tidy_cross_cluster_revoked_certs(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to enable tidying up the cross-cluster
        revoked certificate store.
        """
        return pulumi.get(self, "tidy_cross_cluster_revoked_certs")

    @tidy_cross_cluster_revoked_certs.setter
    def tidy_cross_cluster_revoked_certs(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_cross_cluster_revoked_certs", value)

    @_builtins.property
    @pulumi.getter(name="tidyExpiredIssuers")
    def tidy_expired_issuers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to automatically remove expired issuers past the
        `issuer_safety_buffer`. No keys will be removed as part of this operation.
        """
        return pulumi.get(self, "tidy_expired_issuers")

    @tidy_expired_issuers.setter
    def tidy_expired_issuers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_expired_issuers", value)

    @_builtins.property
    @pulumi.getter(name="tidyMoveLegacyCaBundle")
    def tidy_move_legacy_ca_bundle(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to move the legacy `ca_bundle` from
        `/config/ca_bundle` to `/config/ca_bundle.bak`.
        """
        return pulumi.get(self, "tidy_move_legacy_ca_bundle")

    @tidy_move_legacy_ca_bundle.setter
    def tidy_move_legacy_ca_bundle(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_move_legacy_ca_bundle", value)

    @_builtins.property
    @pulumi.getter(name="tidyRevocationQueue")
    def tidy_revocation_queue(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to remove stale revocation queue entries that
        haven't been confirmed by any active cluster.
        """
        return pulumi.get(self, "tidy_revocation_queue")

    @tidy_revocation_queue.setter
    def tidy_revocation_queue(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_revocation_queue", value)

    @_builtins.property
    @pulumi.getter(name="tidyRevokedCertIssuerAssociations")
    def tidy_revoked_cert_issuer_associations(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to validate issuer associations
        on revocation entries. This helps increase the performance of CRL building and OCSP responses.
        """
        return pulumi.get(self, "tidy_revoked_cert_issuer_associations")

    @tidy_revoked_cert_issuer_associations.setter
    def tidy_revoked_cert_issuer_associations(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_revoked_cert_issuer_associations", value)

    @_builtins.property
    @pulumi.getter(name="tidyRevokedCerts")
    def tidy_revoked_certs(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to true to remove all invalid and expired certificates from
        storage. A revoked storage entry is considered invalid if the entry is empty, or the value within
        the entry is empty. If a certificate is removed due to expiry, the entry will also be removed from
        the CRL, and the CRL will be rotated.
        """
        return pulumi.get(self, "tidy_revoked_certs")

    @tidy_revoked_certs.setter
    def tidy_revoked_certs(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tidy_revoked_certs", value)


@pulumi.type_token("vault:pkiSecret/backendConfigAutoTidy:BackendConfigAutoTidy")
class BackendConfigAutoTidy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acme_account_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 interval_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 maintain_stored_certificate_counts: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 min_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 pause_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 publish_stored_certificate_count_metrics: Optional[pulumi.Input[_builtins.bool]] = None,
                 revocation_queue_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 tidy_acme: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cert_metadata: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cert_store: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cmpv2_nonce_store: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cross_cluster_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_expired_issuers: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_move_legacy_ca_bundle: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revocation_queue: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revoked_cert_issuer_associations: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Allows setting the Auto Tidy configuration on a PKI Secret Backend

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        pki = vault.Mount("pki",
            path="pki",
            type="pki",
            default_lease_ttl_seconds=3600,
            max_lease_ttl_seconds=86400)
        test = vault.pkisecret.BackendConfigAutoTidy("test",
            backend=pki.path,
            enabled=True,
            tidy_cert_store=True,
            interval_duration="1h")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] acme_account_safety_buffer: The amount of time that must pass after creation that an account with no orders is marked revoked, and the amount of time after being marked revoked or deactivated.
        :param pulumi.Input[_builtins.str] backend: The path to the PKI secret backend to
               read the configuration from, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether automatic tidy is enabled or not.
        :param pulumi.Input[_builtins.str] interval_duration: Interval at which to run an auto-tidy operation. This is the time
               between tidy invocations (after one finishes to the start of the next).
        :param pulumi.Input[_builtins.str] issuer_safety_buffer: The amount of extra time that must have passed beyond issuer's
               expiration before it is removed from the backend storage.
        :param pulumi.Input[_builtins.bool] maintain_stored_certificate_counts: This configures whether stored certificate are
               counted upon initialization of the backend, and whether during normal operation, a running count
               of certificates stored is maintained.
        :param pulumi.Input[_builtins.str] max_startup_backoff_duration: The maximum amount of time auto-tidy will be delayed
               after startup.
        :param pulumi.Input[_builtins.str] min_startup_backoff_duration: The minimum amount of time auto-tidy will be delayed
               after startup.
        :param pulumi.Input[_builtins.str] namespace: The namespace of the target resource.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] pause_duration: The amount of time to wait between processing certificates.
        :param pulumi.Input[_builtins.bool] publish_stored_certificate_count_metrics: This configures whether the stored
               certificate count is published to the metrics consumer.
        :param pulumi.Input[_builtins.str] revocation_queue_safety_buffer: The amount of time that must pass from the
               cross-cluster revocation request being initiated to when it will be slated for removal.
        :param pulumi.Input[_builtins.str] safety_buffer: The amount of extra time that must have passed beyond certificate
               expiration before it is removed from the backend storage and/or revocation list.
        :param pulumi.Input[_builtins.bool] tidy_acme: Set to true to enable tidying ACME accounts, orders and authorizations.
        :param pulumi.Input[_builtins.bool] tidy_cert_metadata: Set to true to enable tidying up certificate metadata.
        :param pulumi.Input[_builtins.bool] tidy_cert_store: Set to true to enable tidying up the certificate store
        :param pulumi.Input[_builtins.bool] tidy_cmpv2_nonce_store: Set to true to enable tidying up the CMPv2 nonce store.
        :param pulumi.Input[_builtins.bool] tidy_cross_cluster_revoked_certs: Set to true to enable tidying up the cross-cluster
               revoked certificate store.
        :param pulumi.Input[_builtins.bool] tidy_expired_issuers: Set to true to automatically remove expired issuers past the
               `issuer_safety_buffer`. No keys will be removed as part of this operation.
        :param pulumi.Input[_builtins.bool] tidy_move_legacy_ca_bundle: Set to true to move the legacy `ca_bundle` from
               `/config/ca_bundle` to `/config/ca_bundle.bak`.
        :param pulumi.Input[_builtins.bool] tidy_revocation_queue: Set to true to remove stale revocation queue entries that
               haven't been confirmed by any active cluster.
        :param pulumi.Input[_builtins.bool] tidy_revoked_cert_issuer_associations: Set to true to validate issuer associations
               on revocation entries. This helps increase the performance of CRL building and OCSP responses.
        :param pulumi.Input[_builtins.bool] tidy_revoked_certs: Set to true to remove all invalid and expired certificates from
               storage. A revoked storage entry is considered invalid if the entry is empty, or the value within
               the entry is empty. If a certificate is removed due to expiry, the entry will also be removed from
               the CRL, and the CRL will be rotated.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BackendConfigAutoTidyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Allows setting the Auto Tidy configuration on a PKI Secret Backend

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        pki = vault.Mount("pki",
            path="pki",
            type="pki",
            default_lease_ttl_seconds=3600,
            max_lease_ttl_seconds=86400)
        test = vault.pkisecret.BackendConfigAutoTidy("test",
            backend=pki.path,
            enabled=True,
            tidy_cert_store=True,
            interval_duration="1h")
        ```

        :param str resource_name: The name of the resource.
        :param BackendConfigAutoTidyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BackendConfigAutoTidyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acme_account_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 interval_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 maintain_stored_certificate_counts: Optional[pulumi.Input[_builtins.bool]] = None,
                 max_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 min_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 pause_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 publish_stored_certificate_count_metrics: Optional[pulumi.Input[_builtins.bool]] = None,
                 revocation_queue_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
                 tidy_acme: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cert_metadata: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cert_store: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cmpv2_nonce_store: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_cross_cluster_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_expired_issuers: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_move_legacy_ca_bundle: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revocation_queue: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revoked_cert_issuer_associations: Optional[pulumi.Input[_builtins.bool]] = None,
                 tidy_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BackendConfigAutoTidyArgs.__new__(BackendConfigAutoTidyArgs)

            __props__.__dict__["acme_account_safety_buffer"] = acme_account_safety_buffer
            if backend is None and not opts.urn:
                raise TypeError("Missing required property 'backend'")
            __props__.__dict__["backend"] = backend
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["interval_duration"] = interval_duration
            __props__.__dict__["issuer_safety_buffer"] = issuer_safety_buffer
            __props__.__dict__["maintain_stored_certificate_counts"] = maintain_stored_certificate_counts
            __props__.__dict__["max_startup_backoff_duration"] = max_startup_backoff_duration
            __props__.__dict__["min_startup_backoff_duration"] = min_startup_backoff_duration
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["pause_duration"] = pause_duration
            __props__.__dict__["publish_stored_certificate_count_metrics"] = publish_stored_certificate_count_metrics
            __props__.__dict__["revocation_queue_safety_buffer"] = revocation_queue_safety_buffer
            __props__.__dict__["safety_buffer"] = safety_buffer
            __props__.__dict__["tidy_acme"] = tidy_acme
            __props__.__dict__["tidy_cert_metadata"] = tidy_cert_metadata
            __props__.__dict__["tidy_cert_store"] = tidy_cert_store
            __props__.__dict__["tidy_cmpv2_nonce_store"] = tidy_cmpv2_nonce_store
            __props__.__dict__["tidy_cross_cluster_revoked_certs"] = tidy_cross_cluster_revoked_certs
            __props__.__dict__["tidy_expired_issuers"] = tidy_expired_issuers
            __props__.__dict__["tidy_move_legacy_ca_bundle"] = tidy_move_legacy_ca_bundle
            __props__.__dict__["tidy_revocation_queue"] = tidy_revocation_queue
            __props__.__dict__["tidy_revoked_cert_issuer_associations"] = tidy_revoked_cert_issuer_associations
            __props__.__dict__["tidy_revoked_certs"] = tidy_revoked_certs
        super(BackendConfigAutoTidy, __self__).__init__(
            'vault:pkiSecret/backendConfigAutoTidy:BackendConfigAutoTidy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acme_account_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
            backend: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            interval_duration: Optional[pulumi.Input[_builtins.str]] = None,
            issuer_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
            maintain_stored_certificate_counts: Optional[pulumi.Input[_builtins.bool]] = None,
            max_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
            min_startup_backoff_duration: Optional[pulumi.Input[_builtins.str]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None,
            pause_duration: Optional[pulumi.Input[_builtins.str]] = None,
            publish_stored_certificate_count_metrics: Optional[pulumi.Input[_builtins.bool]] = None,
            revocation_queue_safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
            safety_buffer: Optional[pulumi.Input[_builtins.str]] = None,
            tidy_acme: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_cert_metadata: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_cert_store: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_cmpv2_nonce_store: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_cross_cluster_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_expired_issuers: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_move_legacy_ca_bundle: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_revocation_queue: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_revoked_cert_issuer_associations: Optional[pulumi.Input[_builtins.bool]] = None,
            tidy_revoked_certs: Optional[pulumi.Input[_builtins.bool]] = None) -> 'BackendConfigAutoTidy':
        """
        Get an existing BackendConfigAutoTidy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] acme_account_safety_buffer: The amount of time that must pass after creation that an account with no orders is marked revoked, and the amount of time after being marked revoked or deactivated.
        :param pulumi.Input[_builtins.str] backend: The path to the PKI secret backend to
               read the configuration from, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether automatic tidy is enabled or not.
        :param pulumi.Input[_builtins.str] interval_duration: Interval at which to run an auto-tidy operation. This is the time
               between tidy invocations (after one finishes to the start of the next).
        :param pulumi.Input[_builtins.str] issuer_safety_buffer: The amount of extra time that must have passed beyond issuer's
               expiration before it is removed from the backend storage.
        :param pulumi.Input[_builtins.bool] maintain_stored_certificate_counts: This configures whether stored certificate are
               counted upon initialization of the backend, and whether during normal operation, a running count
               of certificates stored is maintained.
        :param pulumi.Input[_builtins.str] max_startup_backoff_duration: The maximum amount of time auto-tidy will be delayed
               after startup.
        :param pulumi.Input[_builtins.str] min_startup_backoff_duration: The minimum amount of time auto-tidy will be delayed
               after startup.
        :param pulumi.Input[_builtins.str] namespace: The namespace of the target resource.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] pause_duration: The amount of time to wait between processing certificates.
        :param pulumi.Input[_builtins.bool] publish_stored_certificate_count_metrics: This configures whether the stored
               certificate count is published to the metrics consumer.
        :param pulumi.Input[_builtins.str] revocation_queue_safety_buffer: The amount of time that must pass from the
               cross-cluster revocation request being initiated to when it will be slated for removal.
        :param pulumi.Input[_builtins.str] safety_buffer: The amount of extra time that must have passed beyond certificate
               expiration before it is removed from the backend storage and/or revocation list.
        :param pulumi.Input[_builtins.bool] tidy_acme: Set to true to enable tidying ACME accounts, orders and authorizations.
        :param pulumi.Input[_builtins.bool] tidy_cert_metadata: Set to true to enable tidying up certificate metadata.
        :param pulumi.Input[_builtins.bool] tidy_cert_store: Set to true to enable tidying up the certificate store
        :param pulumi.Input[_builtins.bool] tidy_cmpv2_nonce_store: Set to true to enable tidying up the CMPv2 nonce store.
        :param pulumi.Input[_builtins.bool] tidy_cross_cluster_revoked_certs: Set to true to enable tidying up the cross-cluster
               revoked certificate store.
        :param pulumi.Input[_builtins.bool] tidy_expired_issuers: Set to true to automatically remove expired issuers past the
               `issuer_safety_buffer`. No keys will be removed as part of this operation.
        :param pulumi.Input[_builtins.bool] tidy_move_legacy_ca_bundle: Set to true to move the legacy `ca_bundle` from
               `/config/ca_bundle` to `/config/ca_bundle.bak`.
        :param pulumi.Input[_builtins.bool] tidy_revocation_queue: Set to true to remove stale revocation queue entries that
               haven't been confirmed by any active cluster.
        :param pulumi.Input[_builtins.bool] tidy_revoked_cert_issuer_associations: Set to true to validate issuer associations
               on revocation entries. This helps increase the performance of CRL building and OCSP responses.
        :param pulumi.Input[_builtins.bool] tidy_revoked_certs: Set to true to remove all invalid and expired certificates from
               storage. A revoked storage entry is considered invalid if the entry is empty, or the value within
               the entry is empty. If a certificate is removed due to expiry, the entry will also be removed from
               the CRL, and the CRL will be rotated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BackendConfigAutoTidyState.__new__(_BackendConfigAutoTidyState)

        __props__.__dict__["acme_account_safety_buffer"] = acme_account_safety_buffer
        __props__.__dict__["backend"] = backend
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["interval_duration"] = interval_duration
        __props__.__dict__["issuer_safety_buffer"] = issuer_safety_buffer
        __props__.__dict__["maintain_stored_certificate_counts"] = maintain_stored_certificate_counts
        __props__.__dict__["max_startup_backoff_duration"] = max_startup_backoff_duration
        __props__.__dict__["min_startup_backoff_duration"] = min_startup_backoff_duration
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["pause_duration"] = pause_duration
        __props__.__dict__["publish_stored_certificate_count_metrics"] = publish_stored_certificate_count_metrics
        __props__.__dict__["revocation_queue_safety_buffer"] = revocation_queue_safety_buffer
        __props__.__dict__["safety_buffer"] = safety_buffer
        __props__.__dict__["tidy_acme"] = tidy_acme
        __props__.__dict__["tidy_cert_metadata"] = tidy_cert_metadata
        __props__.__dict__["tidy_cert_store"] = tidy_cert_store
        __props__.__dict__["tidy_cmpv2_nonce_store"] = tidy_cmpv2_nonce_store
        __props__.__dict__["tidy_cross_cluster_revoked_certs"] = tidy_cross_cluster_revoked_certs
        __props__.__dict__["tidy_expired_issuers"] = tidy_expired_issuers
        __props__.__dict__["tidy_move_legacy_ca_bundle"] = tidy_move_legacy_ca_bundle
        __props__.__dict__["tidy_revocation_queue"] = tidy_revocation_queue
        __props__.__dict__["tidy_revoked_cert_issuer_associations"] = tidy_revoked_cert_issuer_associations
        __props__.__dict__["tidy_revoked_certs"] = tidy_revoked_certs
        return BackendConfigAutoTidy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="acmeAccountSafetyBuffer")
    def acme_account_safety_buffer(self) -> pulumi.Output[_builtins.str]:
        """
        The amount of time that must pass after creation that an account with no orders is marked revoked, and the amount of time after being marked revoked or deactivated.
        """
        return pulumi.get(self, "acme_account_safety_buffer")

    @_builtins.property
    @pulumi.getter
    def backend(self) -> pulumi.Output[_builtins.str]:
        """
        The path to the PKI secret backend to
        read the configuration from, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Specifies whether automatic tidy is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="intervalDuration")
    def interval_duration(self) -> pulumi.Output[_builtins.str]:
        """
        Interval at which to run an auto-tidy operation. This is the time
        between tidy invocations (after one finishes to the start of the next).
        """
        return pulumi.get(self, "interval_duration")

    @_builtins.property
    @pulumi.getter(name="issuerSafetyBuffer")
    def issuer_safety_buffer(self) -> pulumi.Output[_builtins.str]:
        """
        The amount of extra time that must have passed beyond issuer's
        expiration before it is removed from the backend storage.
        """
        return pulumi.get(self, "issuer_safety_buffer")

    @_builtins.property
    @pulumi.getter(name="maintainStoredCertificateCounts")
    def maintain_stored_certificate_counts(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        This configures whether stored certificate are
        counted upon initialization of the backend, and whether during normal operation, a running count
        of certificates stored is maintained.
        """
        return pulumi.get(self, "maintain_stored_certificate_counts")

    @_builtins.property
    @pulumi.getter(name="maxStartupBackoffDuration")
    def max_startup_backoff_duration(self) -> pulumi.Output[_builtins.str]:
        """
        The maximum amount of time auto-tidy will be delayed
        after startup.
        """
        return pulumi.get(self, "max_startup_backoff_duration")

    @_builtins.property
    @pulumi.getter(name="minStartupBackoffDuration")
    def min_startup_backoff_duration(self) -> pulumi.Output[_builtins.str]:
        """
        The minimum amount of time auto-tidy will be delayed
        after startup.
        """
        return pulumi.get(self, "min_startup_backoff_duration")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The namespace of the target resource.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="pauseDuration")
    def pause_duration(self) -> pulumi.Output[_builtins.str]:
        """
        The amount of time to wait between processing certificates.
        """
        return pulumi.get(self, "pause_duration")

    @_builtins.property
    @pulumi.getter(name="publishStoredCertificateCountMetrics")
    def publish_stored_certificate_count_metrics(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        This configures whether the stored
        certificate count is published to the metrics consumer.
        """
        return pulumi.get(self, "publish_stored_certificate_count_metrics")

    @_builtins.property
    @pulumi.getter(name="revocationQueueSafetyBuffer")
    def revocation_queue_safety_buffer(self) -> pulumi.Output[_builtins.str]:
        """
        The amount of time that must pass from the
        cross-cluster revocation request being initiated to when it will be slated for removal.
        """
        return pulumi.get(self, "revocation_queue_safety_buffer")

    @_builtins.property
    @pulumi.getter(name="safetyBuffer")
    def safety_buffer(self) -> pulumi.Output[_builtins.str]:
        """
        The amount of extra time that must have passed beyond certificate
        expiration before it is removed from the backend storage and/or revocation list.
        """
        return pulumi.get(self, "safety_buffer")

    @_builtins.property
    @pulumi.getter(name="tidyAcme")
    def tidy_acme(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to enable tidying ACME accounts, orders and authorizations.
        """
        return pulumi.get(self, "tidy_acme")

    @_builtins.property
    @pulumi.getter(name="tidyCertMetadata")
    def tidy_cert_metadata(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to enable tidying up certificate metadata.
        """
        return pulumi.get(self, "tidy_cert_metadata")

    @_builtins.property
    @pulumi.getter(name="tidyCertStore")
    def tidy_cert_store(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to enable tidying up the certificate store
        """
        return pulumi.get(self, "tidy_cert_store")

    @_builtins.property
    @pulumi.getter(name="tidyCmpv2NonceStore")
    def tidy_cmpv2_nonce_store(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to enable tidying up the CMPv2 nonce store.
        """
        return pulumi.get(self, "tidy_cmpv2_nonce_store")

    @_builtins.property
    @pulumi.getter(name="tidyCrossClusterRevokedCerts")
    def tidy_cross_cluster_revoked_certs(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to enable tidying up the cross-cluster
        revoked certificate store.
        """
        return pulumi.get(self, "tidy_cross_cluster_revoked_certs")

    @_builtins.property
    @pulumi.getter(name="tidyExpiredIssuers")
    def tidy_expired_issuers(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to automatically remove expired issuers past the
        `issuer_safety_buffer`. No keys will be removed as part of this operation.
        """
        return pulumi.get(self, "tidy_expired_issuers")

    @_builtins.property
    @pulumi.getter(name="tidyMoveLegacyCaBundle")
    def tidy_move_legacy_ca_bundle(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to move the legacy `ca_bundle` from
        `/config/ca_bundle` to `/config/ca_bundle.bak`.
        """
        return pulumi.get(self, "tidy_move_legacy_ca_bundle")

    @_builtins.property
    @pulumi.getter(name="tidyRevocationQueue")
    def tidy_revocation_queue(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to remove stale revocation queue entries that
        haven't been confirmed by any active cluster.
        """
        return pulumi.get(self, "tidy_revocation_queue")

    @_builtins.property
    @pulumi.getter(name="tidyRevokedCertIssuerAssociations")
    def tidy_revoked_cert_issuer_associations(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to validate issuer associations
        on revocation entries. This helps increase the performance of CRL building and OCSP responses.
        """
        return pulumi.get(self, "tidy_revoked_cert_issuer_associations")

    @_builtins.property
    @pulumi.getter(name="tidyRevokedCerts")
    def tidy_revoked_certs(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to true to remove all invalid and expired certificates from
        storage. A revoked storage entry is considered invalid if the entry is empty, or the value within
        the entry is empty. If a certificate is removed due to expiry, the entry will also be removed from
        the CRL, and the CRL will be rotated.
        """
        return pulumi.get(self, "tidy_revoked_certs")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BackendConfigScepArgs', 'BackendConfigScep']

@pulumi.input_type
class BackendConfigScepArgs:
    def __init__(__self__, *,
                 backend: pulumi.Input[_builtins.str],
                 allowed_digest_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_encryption_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 authenticators: Optional[pulumi.Input['BackendConfigScepAuthenticatorsArgs']] = None,
                 default_path_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_validations: Optional[pulumi.Input[Sequence[pulumi.Input['BackendConfigScepExternalValidationArgs']]]] = None,
                 log_level: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 restrict_ca_chain_to_issuer: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a BackendConfigScep resource.
        :param pulumi.Input[_builtins.str] backend: The path to the PKI secret backend to
               read the SCEP configuration from, with no leading or trailing `/`s.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_digest_algorithms: List of allowed digest algorithms for SCEP requests.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_encryption_algorithms: List of allowed encryption algorithms for SCEP requests.
        :param pulumi.Input['BackendConfigScepAuthenticatorsArgs'] authenticators: Lists the mount accessors SCEP should delegate authentication requests towards (see below for nested schema).
        :param pulumi.Input[_builtins.str] default_path_policy: Specifies the policy to be used for non-role-qualified SCEP requests; valid values are 'sign-verbatim', or "role:<role_name>" to specify a role to use as this policy.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether SCEP is enabled.
        :param pulumi.Input[Sequence[pulumi.Input['BackendConfigScepExternalValidationArgs']]] external_validations: Lists the 3rd party validation of SCEP requests (see below for nested schema).
        :param pulumi.Input[_builtins.str] log_level: The level of logging verbosity, affects only SCEP logs on this mount.
               
               
               <a id="nestedatt--authenticators"></a>
        :param pulumi.Input[_builtins.str] namespace: The namespace of the target resource.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.bool] restrict_ca_chain_to_issuer: If true, only return the issuer CA, otherwise the entire CA certificate chain will be returned if available from the PKI mount.
        """
        pulumi.set(__self__, "backend", backend)
        if allowed_digest_algorithms is not None:
            pulumi.set(__self__, "allowed_digest_algorithms", allowed_digest_algorithms)
        if allowed_encryption_algorithms is not None:
            pulumi.set(__self__, "allowed_encryption_algorithms", allowed_encryption_algorithms)
        if authenticators is not None:
            pulumi.set(__self__, "authenticators", authenticators)
        if default_path_policy is not None:
            pulumi.set(__self__, "default_path_policy", default_path_policy)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if external_validations is not None:
            pulumi.set(__self__, "external_validations", external_validations)
        if log_level is not None:
            pulumi.set(__self__, "log_level", log_level)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if restrict_ca_chain_to_issuer is not None:
            pulumi.set(__self__, "restrict_ca_chain_to_issuer", restrict_ca_chain_to_issuer)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> pulumi.Input[_builtins.str]:
        """
        The path to the PKI secret backend to
        read the SCEP configuration from, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter(name="allowedDigestAlgorithms")
    def allowed_digest_algorithms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of allowed digest algorithms for SCEP requests.
        """
        return pulumi.get(self, "allowed_digest_algorithms")

    @allowed_digest_algorithms.setter
    def allowed_digest_algorithms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_digest_algorithms", value)

    @_builtins.property
    @pulumi.getter(name="allowedEncryptionAlgorithms")
    def allowed_encryption_algorithms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of allowed encryption algorithms for SCEP requests.
        """
        return pulumi.get(self, "allowed_encryption_algorithms")

    @allowed_encryption_algorithms.setter
    def allowed_encryption_algorithms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_encryption_algorithms", value)

    @_builtins.property
    @pulumi.getter
    def authenticators(self) -> Optional[pulumi.Input['BackendConfigScepAuthenticatorsArgs']]:
        """
        Lists the mount accessors SCEP should delegate authentication requests towards (see below for nested schema).
        """
        return pulumi.get(self, "authenticators")

    @authenticators.setter
    def authenticators(self, value: Optional[pulumi.Input['BackendConfigScepAuthenticatorsArgs']]):
        pulumi.set(self, "authenticators", value)

    @_builtins.property
    @pulumi.getter(name="defaultPathPolicy")
    def default_path_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the policy to be used for non-role-qualified SCEP requests; valid values are 'sign-verbatim', or "role:<role_name>" to specify a role to use as this policy.
        """
        return pulumi.get(self, "default_path_policy")

    @default_path_policy.setter
    def default_path_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_path_policy", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether SCEP is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="externalValidations")
    def external_validations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackendConfigScepExternalValidationArgs']]]]:
        """
        Lists the 3rd party validation of SCEP requests (see below for nested schema).
        """
        return pulumi.get(self, "external_validations")

    @external_validations.setter
    def external_validations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackendConfigScepExternalValidationArgs']]]]):
        pulumi.set(self, "external_validations", value)

    @_builtins.property
    @pulumi.getter(name="logLevel")
    def log_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The level of logging verbosity, affects only SCEP logs on this mount.


        <a id="nestedatt--authenticators"></a>
        """
        return pulumi.get(self, "log_level")

    @log_level.setter
    def log_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "log_level", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace of the target resource.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="restrictCaChainToIssuer")
    def restrict_ca_chain_to_issuer(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, only return the issuer CA, otherwise the entire CA certificate chain will be returned if available from the PKI mount.
        """
        return pulumi.get(self, "restrict_ca_chain_to_issuer")

    @restrict_ca_chain_to_issuer.setter
    def restrict_ca_chain_to_issuer(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "restrict_ca_chain_to_issuer", value)


@pulumi.input_type
class _BackendConfigScepState:
    def __init__(__self__, *,
                 allowed_digest_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_encryption_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 authenticators: Optional[pulumi.Input['BackendConfigScepAuthenticatorsArgs']] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 default_path_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_validations: Optional[pulumi.Input[Sequence[pulumi.Input['BackendConfigScepExternalValidationArgs']]]] = None,
                 last_updated: Optional[pulumi.Input[_builtins.str]] = None,
                 log_level: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 restrict_ca_chain_to_issuer: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering BackendConfigScep resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_digest_algorithms: List of allowed digest algorithms for SCEP requests.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_encryption_algorithms: List of allowed encryption algorithms for SCEP requests.
        :param pulumi.Input['BackendConfigScepAuthenticatorsArgs'] authenticators: Lists the mount accessors SCEP should delegate authentication requests towards (see below for nested schema).
        :param pulumi.Input[_builtins.str] backend: The path to the PKI secret backend to
               read the SCEP configuration from, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.str] default_path_policy: Specifies the policy to be used for non-role-qualified SCEP requests; valid values are 'sign-verbatim', or "role:<role_name>" to specify a role to use as this policy.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether SCEP is enabled.
        :param pulumi.Input[Sequence[pulumi.Input['BackendConfigScepExternalValidationArgs']]] external_validations: Lists the 3rd party validation of SCEP requests (see below for nested schema).
        :param pulumi.Input[_builtins.str] last_updated: A read-only timestamp representing the last time the configuration was updated.
        :param pulumi.Input[_builtins.str] log_level: The level of logging verbosity, affects only SCEP logs on this mount.
               
               
               <a id="nestedatt--authenticators"></a>
        :param pulumi.Input[_builtins.str] namespace: The namespace of the target resource.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.bool] restrict_ca_chain_to_issuer: If true, only return the issuer CA, otherwise the entire CA certificate chain will be returned if available from the PKI mount.
        """
        if allowed_digest_algorithms is not None:
            pulumi.set(__self__, "allowed_digest_algorithms", allowed_digest_algorithms)
        if allowed_encryption_algorithms is not None:
            pulumi.set(__self__, "allowed_encryption_algorithms", allowed_encryption_algorithms)
        if authenticators is not None:
            pulumi.set(__self__, "authenticators", authenticators)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if default_path_policy is not None:
            pulumi.set(__self__, "default_path_policy", default_path_policy)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if external_validations is not None:
            pulumi.set(__self__, "external_validations", external_validations)
        if last_updated is not None:
            pulumi.set(__self__, "last_updated", last_updated)
        if log_level is not None:
            pulumi.set(__self__, "log_level", log_level)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if restrict_ca_chain_to_issuer is not None:
            pulumi.set(__self__, "restrict_ca_chain_to_issuer", restrict_ca_chain_to_issuer)

    @_builtins.property
    @pulumi.getter(name="allowedDigestAlgorithms")
    def allowed_digest_algorithms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of allowed digest algorithms for SCEP requests.
        """
        return pulumi.get(self, "allowed_digest_algorithms")

    @allowed_digest_algorithms.setter
    def allowed_digest_algorithms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_digest_algorithms", value)

    @_builtins.property
    @pulumi.getter(name="allowedEncryptionAlgorithms")
    def allowed_encryption_algorithms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of allowed encryption algorithms for SCEP requests.
        """
        return pulumi.get(self, "allowed_encryption_algorithms")

    @allowed_encryption_algorithms.setter
    def allowed_encryption_algorithms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_encryption_algorithms", value)

    @_builtins.property
    @pulumi.getter
    def authenticators(self) -> Optional[pulumi.Input['BackendConfigScepAuthenticatorsArgs']]:
        """
        Lists the mount accessors SCEP should delegate authentication requests towards (see below for nested schema).
        """
        return pulumi.get(self, "authenticators")

    @authenticators.setter
    def authenticators(self, value: Optional[pulumi.Input['BackendConfigScepAuthenticatorsArgs']]):
        pulumi.set(self, "authenticators", value)

    @_builtins.property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to the PKI secret backend to
        read the SCEP configuration from, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend", value)

    @_builtins.property
    @pulumi.getter(name="defaultPathPolicy")
    def default_path_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the policy to be used for non-role-qualified SCEP requests; valid values are 'sign-verbatim', or "role:<role_name>" to specify a role to use as this policy.
        """
        return pulumi.get(self, "default_path_policy")

    @default_path_policy.setter
    def default_path_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_path_policy", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether SCEP is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="externalValidations")
    def external_validations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackendConfigScepExternalValidationArgs']]]]:
        """
        Lists the 3rd party validation of SCEP requests (see below for nested schema).
        """
        return pulumi.get(self, "external_validations")

    @external_validations.setter
    def external_validations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackendConfigScepExternalValidationArgs']]]]):
        pulumi.set(self, "external_validations", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A read-only timestamp representing the last time the configuration was updated.
        """
        return pulumi.get(self, "last_updated")

    @last_updated.setter
    def last_updated(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated", value)

    @_builtins.property
    @pulumi.getter(name="logLevel")
    def log_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The level of logging verbosity, affects only SCEP logs on this mount.


        <a id="nestedatt--authenticators"></a>
        """
        return pulumi.get(self, "log_level")

    @log_level.setter
    def log_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "log_level", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace of the target resource.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="restrictCaChainToIssuer")
    def restrict_ca_chain_to_issuer(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, only return the issuer CA, otherwise the entire CA certificate chain will be returned if available from the PKI mount.
        """
        return pulumi.get(self, "restrict_ca_chain_to_issuer")

    @restrict_ca_chain_to_issuer.setter
    def restrict_ca_chain_to_issuer(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "restrict_ca_chain_to_issuer", value)


@pulumi.type_token("vault:pkiSecret/backendConfigScep:BackendConfigScep")
class BackendConfigScep(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_digest_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_encryption_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 authenticators: Optional[pulumi.Input[Union['BackendConfigScepAuthenticatorsArgs', 'BackendConfigScepAuthenticatorsArgsDict']]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 default_path_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_validations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendConfigScepExternalValidationArgs', 'BackendConfigScepExternalValidationArgsDict']]]]] = None,
                 log_level: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 restrict_ca_chain_to_issuer: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Allows setting the SCEP configuration on a PKI Secret Backend.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        scep = vault.AuthBackend("scep",
            path="scep-auth",
            type="scep")
        scep_challenge = vault.ScepAuthBackendRole("scep_challenge",
            backend=scep.id,
            name="scep-auth",
            display_name="Static challenge for SCEP clients",
            auth_type="static-challenge",
            challenge="ac7e4ada-c8ef-4393-9098-d69d08736833")
        pki = vault.Mount("pki",
            path="pki_scep",
            type="pki",
            description="PKI secret engine mount")
        test = vault.pkisecret.BackendConfigScep("test",
            backend=pki.path,
            enabled=True,
            default_path_policy="sign-verbatim",
            restrict_ca_chain_to_issuer=True,
            authenticators={
                "scep": {
                    "accessor": scep.accessor,
                    "scep_role": scep_challenge.name,
                },
            })
        ```

        ## Import

        The PKI config cluster can be imported using the resource's `id`.
        In the case of the example above the `id` would be `pki-root/config/scep`,
        where the `pki-root` component is the resource's `backend`, e.g.

        ```sh
        $ pulumi import vault:pkiSecret/backendConfigScep:BackendConfigScep example pki-root/config/scep
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_digest_algorithms: List of allowed digest algorithms for SCEP requests.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_encryption_algorithms: List of allowed encryption algorithms for SCEP requests.
        :param pulumi.Input[Union['BackendConfigScepAuthenticatorsArgs', 'BackendConfigScepAuthenticatorsArgsDict']] authenticators: Lists the mount accessors SCEP should delegate authentication requests towards (see below for nested schema).
        :param pulumi.Input[_builtins.str] backend: The path to the PKI secret backend to
               read the SCEP configuration from, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.str] default_path_policy: Specifies the policy to be used for non-role-qualified SCEP requests; valid values are 'sign-verbatim', or "role:<role_name>" to specify a role to use as this policy.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether SCEP is enabled.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BackendConfigScepExternalValidationArgs', 'BackendConfigScepExternalValidationArgsDict']]]] external_validations: Lists the 3rd party validation of SCEP requests (see below for nested schema).
        :param pulumi.Input[_builtins.str] log_level: The level of logging verbosity, affects only SCEP logs on this mount.
               
               
               <a id="nestedatt--authenticators"></a>
        :param pulumi.Input[_builtins.str] namespace: The namespace of the target resource.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.bool] restrict_ca_chain_to_issuer: If true, only return the issuer CA, otherwise the entire CA certificate chain will be returned if available from the PKI mount.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BackendConfigScepArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Allows setting the SCEP configuration on a PKI Secret Backend.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        scep = vault.AuthBackend("scep",
            path="scep-auth",
            type="scep")
        scep_challenge = vault.ScepAuthBackendRole("scep_challenge",
            backend=scep.id,
            name="scep-auth",
            display_name="Static challenge for SCEP clients",
            auth_type="static-challenge",
            challenge="ac7e4ada-c8ef-4393-9098-d69d08736833")
        pki = vault.Mount("pki",
            path="pki_scep",
            type="pki",
            description="PKI secret engine mount")
        test = vault.pkisecret.BackendConfigScep("test",
            backend=pki.path,
            enabled=True,
            default_path_policy="sign-verbatim",
            restrict_ca_chain_to_issuer=True,
            authenticators={
                "scep": {
                    "accessor": scep.accessor,
                    "scep_role": scep_challenge.name,
                },
            })
        ```

        ## Import

        The PKI config cluster can be imported using the resource's `id`.
        In the case of the example above the `id` would be `pki-root/config/scep`,
        where the `pki-root` component is the resource's `backend`, e.g.

        ```sh
        $ pulumi import vault:pkiSecret/backendConfigScep:BackendConfigScep example pki-root/config/scep
        ```

        :param str resource_name: The name of the resource.
        :param BackendConfigScepArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BackendConfigScepArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_digest_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_encryption_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 authenticators: Optional[pulumi.Input[Union['BackendConfigScepAuthenticatorsArgs', 'BackendConfigScepAuthenticatorsArgsDict']]] = None,
                 backend: Optional[pulumi.Input[_builtins.str]] = None,
                 default_path_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 external_validations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendConfigScepExternalValidationArgs', 'BackendConfigScepExternalValidationArgsDict']]]]] = None,
                 log_level: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 restrict_ca_chain_to_issuer: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BackendConfigScepArgs.__new__(BackendConfigScepArgs)

            __props__.__dict__["allowed_digest_algorithms"] = allowed_digest_algorithms
            __props__.__dict__["allowed_encryption_algorithms"] = allowed_encryption_algorithms
            __props__.__dict__["authenticators"] = authenticators
            if backend is None and not opts.urn:
                raise TypeError("Missing required property 'backend'")
            __props__.__dict__["backend"] = backend
            __props__.__dict__["default_path_policy"] = default_path_policy
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["external_validations"] = external_validations
            __props__.__dict__["log_level"] = log_level
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["restrict_ca_chain_to_issuer"] = restrict_ca_chain_to_issuer
            __props__.__dict__["last_updated"] = None
        super(BackendConfigScep, __self__).__init__(
            'vault:pkiSecret/backendConfigScep:BackendConfigScep',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_digest_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_encryption_algorithms: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            authenticators: Optional[pulumi.Input[Union['BackendConfigScepAuthenticatorsArgs', 'BackendConfigScepAuthenticatorsArgsDict']]] = None,
            backend: Optional[pulumi.Input[_builtins.str]] = None,
            default_path_policy: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            external_validations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackendConfigScepExternalValidationArgs', 'BackendConfigScepExternalValidationArgsDict']]]]] = None,
            last_updated: Optional[pulumi.Input[_builtins.str]] = None,
            log_level: Optional[pulumi.Input[_builtins.str]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None,
            restrict_ca_chain_to_issuer: Optional[pulumi.Input[_builtins.bool]] = None) -> 'BackendConfigScep':
        """
        Get an existing BackendConfigScep resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_digest_algorithms: List of allowed digest algorithms for SCEP requests.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_encryption_algorithms: List of allowed encryption algorithms for SCEP requests.
        :param pulumi.Input[Union['BackendConfigScepAuthenticatorsArgs', 'BackendConfigScepAuthenticatorsArgsDict']] authenticators: Lists the mount accessors SCEP should delegate authentication requests towards (see below for nested schema).
        :param pulumi.Input[_builtins.str] backend: The path to the PKI secret backend to
               read the SCEP configuration from, with no leading or trailing `/`s.
        :param pulumi.Input[_builtins.str] default_path_policy: Specifies the policy to be used for non-role-qualified SCEP requests; valid values are 'sign-verbatim', or "role:<role_name>" to specify a role to use as this policy.
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether SCEP is enabled.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BackendConfigScepExternalValidationArgs', 'BackendConfigScepExternalValidationArgsDict']]]] external_validations: Lists the 3rd party validation of SCEP requests (see below for nested schema).
        :param pulumi.Input[_builtins.str] last_updated: A read-only timestamp representing the last time the configuration was updated.
        :param pulumi.Input[_builtins.str] log_level: The level of logging verbosity, affects only SCEP logs on this mount.
               
               
               <a id="nestedatt--authenticators"></a>
        :param pulumi.Input[_builtins.str] namespace: The namespace of the target resource.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.bool] restrict_ca_chain_to_issuer: If true, only return the issuer CA, otherwise the entire CA certificate chain will be returned if available from the PKI mount.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BackendConfigScepState.__new__(_BackendConfigScepState)

        __props__.__dict__["allowed_digest_algorithms"] = allowed_digest_algorithms
        __props__.__dict__["allowed_encryption_algorithms"] = allowed_encryption_algorithms
        __props__.__dict__["authenticators"] = authenticators
        __props__.__dict__["backend"] = backend
        __props__.__dict__["default_path_policy"] = default_path_policy
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["external_validations"] = external_validations
        __props__.__dict__["last_updated"] = last_updated
        __props__.__dict__["log_level"] = log_level
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["restrict_ca_chain_to_issuer"] = restrict_ca_chain_to_issuer
        return BackendConfigScep(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowedDigestAlgorithms")
    def allowed_digest_algorithms(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of allowed digest algorithms for SCEP requests.
        """
        return pulumi.get(self, "allowed_digest_algorithms")

    @_builtins.property
    @pulumi.getter(name="allowedEncryptionAlgorithms")
    def allowed_encryption_algorithms(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of allowed encryption algorithms for SCEP requests.
        """
        return pulumi.get(self, "allowed_encryption_algorithms")

    @_builtins.property
    @pulumi.getter
    def authenticators(self) -> pulumi.Output['outputs.BackendConfigScepAuthenticators']:
        """
        Lists the mount accessors SCEP should delegate authentication requests towards (see below for nested schema).
        """
        return pulumi.get(self, "authenticators")

    @_builtins.property
    @pulumi.getter
    def backend(self) -> pulumi.Output[_builtins.str]:
        """
        The path to the PKI secret backend to
        read the SCEP configuration from, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @_builtins.property
    @pulumi.getter(name="defaultPathPolicy")
    def default_path_policy(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the policy to be used for non-role-qualified SCEP requests; valid values are 'sign-verbatim', or "role:<role_name>" to specify a role to use as this policy.
        """
        return pulumi.get(self, "default_path_policy")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Specifies whether SCEP is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="externalValidations")
    def external_validations(self) -> pulumi.Output[Sequence['outputs.BackendConfigScepExternalValidation']]:
        """
        Lists the 3rd party validation of SCEP requests (see below for nested schema).
        """
        return pulumi.get(self, "external_validations")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> pulumi.Output[_builtins.str]:
        """
        A read-only timestamp representing the last time the configuration was updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="logLevel")
    def log_level(self) -> pulumi.Output[_builtins.str]:
        """
        The level of logging verbosity, affects only SCEP logs on this mount.


        <a id="nestedatt--authenticators"></a>
        """
        return pulumi.get(self, "log_level")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The namespace of the target resource.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="restrictCaChainToIssuer")
    def restrict_ca_chain_to_issuer(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If true, only return the issuer CA, otherwise the entire CA certificate chain will be returned if available from the PKI mount.
        """
        return pulumi.get(self, "restrict_ca_chain_to_issuer")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AuthBackendCustomEndpointArgs',
    'AuthBackendCustomEndpointArgsDict',
    'AuthBackendTuneArgs',
    'AuthBackendTuneArgsDict',
    'SecretRolesetBindingArgs',
    'SecretRolesetBindingArgsDict',
    'SecretStaticAccountBindingArgs',
    'SecretStaticAccountBindingArgsDict',
]

MYPY = False

if not MYPY:
    class AuthBackendCustomEndpointArgsDict(TypedDict):
        api: NotRequired[pulumi.Input[_builtins.str]]
        """
        Replaces the service endpoint used in API requests to `https://www.googleapis.com`.
        """
        compute: NotRequired[pulumi.Input[_builtins.str]]
        """
        Replaces the service endpoint used in API requests to `https://compute.googleapis.com`.

        The endpoint value provided for a given key has the form of `scheme://host:port`.
        The `scheme://` and `:port` portions of the endpoint value are optional.
        """
        crm: NotRequired[pulumi.Input[_builtins.str]]
        """
        Replaces the service endpoint used in API requests to `https://cloudresourcemanager.googleapis.com`.
        """
        iam: NotRequired[pulumi.Input[_builtins.str]]
        """
        Replaces the service endpoint used in API requests to `https://iam.googleapis.com`.
        """
elif False:
    AuthBackendCustomEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AuthBackendCustomEndpointArgs:
    def __init__(__self__, *,
                 api: Optional[pulumi.Input[_builtins.str]] = None,
                 compute: Optional[pulumi.Input[_builtins.str]] = None,
                 crm: Optional[pulumi.Input[_builtins.str]] = None,
                 iam: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] api: Replaces the service endpoint used in API requests to `https://www.googleapis.com`.
        :param pulumi.Input[_builtins.str] compute: Replaces the service endpoint used in API requests to `https://compute.googleapis.com`.
               
               The endpoint value provided for a given key has the form of `scheme://host:port`.
               The `scheme://` and `:port` portions of the endpoint value are optional.
        :param pulumi.Input[_builtins.str] crm: Replaces the service endpoint used in API requests to `https://cloudresourcemanager.googleapis.com`.
        :param pulumi.Input[_builtins.str] iam: Replaces the service endpoint used in API requests to `https://iam.googleapis.com`.
        """
        if api is not None:
            pulumi.set(__self__, "api", api)
        if compute is not None:
            pulumi.set(__self__, "compute", compute)
        if crm is not None:
            pulumi.set(__self__, "crm", crm)
        if iam is not None:
            pulumi.set(__self__, "iam", iam)

    @_builtins.property
    @pulumi.getter
    def api(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Replaces the service endpoint used in API requests to `https://www.googleapis.com`.
        """
        return pulumi.get(self, "api")

    @api.setter
    def api(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api", value)

    @_builtins.property
    @pulumi.getter
    def compute(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Replaces the service endpoint used in API requests to `https://compute.googleapis.com`.

        The endpoint value provided for a given key has the form of `scheme://host:port`.
        The `scheme://` and `:port` portions of the endpoint value are optional.
        """
        return pulumi.get(self, "compute")

    @compute.setter
    def compute(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "compute", value)

    @_builtins.property
    @pulumi.getter
    def crm(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Replaces the service endpoint used in API requests to `https://cloudresourcemanager.googleapis.com`.
        """
        return pulumi.get(self, "crm")

    @crm.setter
    def crm(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "crm", value)

    @_builtins.property
    @pulumi.getter
    def iam(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Replaces the service endpoint used in API requests to `https://iam.googleapis.com`.
        """
        return pulumi.get(self, "iam")

    @iam.setter
    def iam(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "iam", value)


if not MYPY:
    class AuthBackendTuneArgsDict(TypedDict):
        allowed_response_headers: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        List of headers to whitelist and allowing
        a plugin to include them in the response.
        """
        audit_non_hmac_request_keys: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        Specifies the list of keys that will
        not be HMAC'd by audit devices in the request data object.
        """
        audit_non_hmac_response_keys: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        Specifies the list of keys that will
        not be HMAC'd by audit devices in the response data object.
        """
        default_lease_ttl: NotRequired[pulumi.Input[_builtins.str]]
        """
        Specifies the default time-to-live.
        If set, this overrides the global default.
        Must be a valid [duration string](https://golang.org/pkg/time/#ParseDuration)
        """
        listing_visibility: NotRequired[pulumi.Input[_builtins.str]]
        """
        Specifies whether to show this mount in
        the UI-specific listing endpoint. Valid values are "unauth" or "hidden".
        """
        max_lease_ttl: NotRequired[pulumi.Input[_builtins.str]]
        """
        Specifies the maximum time-to-live.
        If set, this overrides the global default.
        Must be a valid [duration string](https://golang.org/pkg/time/#ParseDuration)
        """
        passthrough_request_headers: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        List of headers to whitelist and
        pass from the request to the backend.
        """
        token_type: NotRequired[pulumi.Input[_builtins.str]]
        """
        Specifies the type of tokens that should be returned by
        the mount. Valid values are "default-service", "default-batch", "service", "batch".


        For more details on the usage of each argument consult the [Vault GCP API documentation](https://www.vaultproject.io/api-docs/auth/gcp#configure).
        """
elif False:
    AuthBackendTuneArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AuthBackendTuneArgs:
    def __init__(__self__, *,
                 allowed_response_headers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 audit_non_hmac_request_keys: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 audit_non_hmac_response_keys: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 default_lease_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 listing_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 max_lease_ttl: Optional[pulumi.Input[_builtins.str]] = None,
                 passthrough_request_headers: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_response_headers: List of headers to whitelist and allowing
               a plugin to include them in the response.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] audit_non_hmac_request_keys: Specifies the list of keys that will
               not be HMAC'd by audit devices in the request data object.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] audit_non_hmac_response_keys: Specifies the list of keys that will
               not be HMAC'd by audit devices in the response data object.
        :param pulumi.Input[_builtins.str] default_lease_ttl: Specifies the default time-to-live.
               If set, this overrides the global default.
               Must be a valid [duration string](https://golang.org/pkg/time/#ParseDuration)
        :param pulumi.Input[_builtins.str] listing_visibility: Specifies whether to show this mount in
               the UI-specific listing endpoint. Valid values are "unauth" or "hidden".
        :param pulumi.Input[_builtins.str] max_lease_ttl: Specifies the maximum time-to-live.
               If set, this overrides the global default.
               Must be a valid [duration string](https://golang.org/pkg/time/#ParseDuration)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] passthrough_request_headers: List of headers to whitelist and
               pass from the request to the backend.
        :param pulumi.Input[_builtins.str] token_type: Specifies the type of tokens that should be returned by
               the mount. Valid values are "default-service", "default-batch", "service", "batch".
               
               
               For more details on the usage of each argument consult the [Vault GCP API documentation](https://www.vaultproject.io/api-docs/auth/gcp#configure).
        """
        if allowed_response_headers is not None:
            pulumi.set(__self__, "allowed_response_headers", allowed_response_headers)
        if audit_non_hmac_request_keys is not None:
            pulumi.set(__self__, "audit_non_hmac_request_keys", audit_non_hmac_request_keys)
        if audit_non_hmac_response_keys is not None:
            pulumi.set(__self__, "audit_non_hmac_response_keys", audit_non_hmac_response_keys)
        if default_lease_ttl is not None:
            pulumi.set(__self__, "default_lease_ttl", default_lease_ttl)
        if listing_visibility is not None:
            pulumi.set(__self__, "listing_visibility", listing_visibility)
        if max_lease_ttl is not None:
            pulumi.set(__self__, "max_lease_ttl", max_lease_ttl)
        if passthrough_request_headers is not None:
            pulumi.set(__self__, "passthrough_request_headers", passthrough_request_headers)
        if token_type is not None:
            pulumi.set(__self__, "token_type", token_type)

    @_builtins.property
    @pulumi.getter(name="allowedResponseHeaders")
    def allowed_response_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of headers to whitelist and allowing
        a plugin to include them in the response.
        """
        return pulumi.get(self, "allowed_response_headers")

    @allowed_response_headers.setter
    def allowed_response_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_response_headers", value)

    @_builtins.property
    @pulumi.getter(name="auditNonHmacRequestKeys")
    def audit_non_hmac_request_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies the list of keys that will
        not be HMAC'd by audit devices in the request data object.
        """
        return pulumi.get(self, "audit_non_hmac_request_keys")

    @audit_non_hmac_request_keys.setter
    def audit_non_hmac_request_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "audit_non_hmac_request_keys", value)

    @_builtins.property
    @pulumi.getter(name="auditNonHmacResponseKeys")
    def audit_non_hmac_response_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies the list of keys that will
        not be HMAC'd by audit devices in the response data object.
        """
        return pulumi.get(self, "audit_non_hmac_response_keys")

    @audit_non_hmac_response_keys.setter
    def audit_non_hmac_response_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "audit_non_hmac_response_keys", value)

    @_builtins.property
    @pulumi.getter(name="defaultLeaseTtl")
    def default_lease_ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the default time-to-live.
        If set, this overrides the global default.
        Must be a valid [duration string](https://golang.org/pkg/time/#ParseDuration)
        """
        return pulumi.get(self, "default_lease_ttl")

    @default_lease_ttl.setter
    def default_lease_ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_lease_ttl", value)

    @_builtins.property
    @pulumi.getter(name="listingVisibility")
    def listing_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether to show this mount in
        the UI-specific listing endpoint. Valid values are "unauth" or "hidden".
        """
        return pulumi.get(self, "listing_visibility")

    @listing_visibility.setter
    def listing_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "listing_visibility", value)

    @_builtins.property
    @pulumi.getter(name="maxLeaseTtl")
    def max_lease_ttl(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the maximum time-to-live.
        If set, this overrides the global default.
        Must be a valid [duration string](https://golang.org/pkg/time/#ParseDuration)
        """
        return pulumi.get(self, "max_lease_ttl")

    @max_lease_ttl.setter
    def max_lease_ttl(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "max_lease_ttl", value)

    @_builtins.property
    @pulumi.getter(name="passthroughRequestHeaders")
    def passthrough_request_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of headers to whitelist and
        pass from the request to the backend.
        """
        return pulumi.get(self, "passthrough_request_headers")

    @passthrough_request_headers.setter
    def passthrough_request_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "passthrough_request_headers", value)

    @_builtins.property
    @pulumi.getter(name="tokenType")
    def token_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of tokens that should be returned by
        the mount. Valid values are "default-service", "default-batch", "service", "batch".


        For more details on the usage of each argument consult the [Vault GCP API documentation](https://www.vaultproject.io/api-docs/auth/gcp#configure).
        """
        return pulumi.get(self, "token_type")

    @token_type.setter
    def token_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token_type", value)


if not MYPY:
    class SecretRolesetBindingArgsDict(TypedDict):
        resource: pulumi.Input[_builtins.str]
        """
        Resource or resource path for which IAM policy information will be bound. The resource path may be specified in a few different [formats](https://www.vaultproject.io/docs/secrets/gcp/index.html#roleset-bindings).
        """
        roles: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]
        """
        List of [GCP IAM roles](https://cloud.google.com/iam/docs/understanding-roles) for the resource.
        """
elif False:
    SecretRolesetBindingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SecretRolesetBindingArgs:
    def __init__(__self__, *,
                 resource: pulumi.Input[_builtins.str],
                 roles: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        """
        :param pulumi.Input[_builtins.str] resource: Resource or resource path for which IAM policy information will be bound. The resource path may be specified in a few different [formats](https://www.vaultproject.io/docs/secrets/gcp/index.html#roleset-bindings).
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] roles: List of [GCP IAM roles](https://cloud.google.com/iam/docs/understanding-roles) for the resource.
        """
        pulumi.set(__self__, "resource", resource)
        pulumi.set(__self__, "roles", roles)

    @_builtins.property
    @pulumi.getter
    def resource(self) -> pulumi.Input[_builtins.str]:
        """
        Resource or resource path for which IAM policy information will be bound. The resource path may be specified in a few different [formats](https://www.vaultproject.io/docs/secrets/gcp/index.html#roleset-bindings).
        """
        return pulumi.get(self, "resource")

    @resource.setter
    def resource(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource", value)

    @_builtins.property
    @pulumi.getter
    def roles(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        List of [GCP IAM roles](https://cloud.google.com/iam/docs/understanding-roles) for the resource.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "roles", value)


if not MYPY:
    class SecretStaticAccountBindingArgsDict(TypedDict):
        resource: pulumi.Input[_builtins.str]
        """
        Resource or resource path for which IAM policy information will be bound. The resource path may be specified in a few different [formats](https://www.vaultproject.io/docs/secrets/gcp/index.html#bindings).
        """
        roles: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]
        """
        List of [GCP IAM roles](https://cloud.google.com/iam/docs/understanding-roles) for the resource.
        """
elif False:
    SecretStaticAccountBindingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SecretStaticAccountBindingArgs:
    def __init__(__self__, *,
                 resource: pulumi.Input[_builtins.str],
                 roles: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        """
        :param pulumi.Input[_builtins.str] resource: Resource or resource path for which IAM policy information will be bound. The resource path may be specified in a few different [formats](https://www.vaultproject.io/docs/secrets/gcp/index.html#bindings).
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] roles: List of [GCP IAM roles](https://cloud.google.com/iam/docs/understanding-roles) for the resource.
        """
        pulumi.set(__self__, "resource", resource)
        pulumi.set(__self__, "roles", roles)

    @_builtins.property
    @pulumi.getter
    def resource(self) -> pulumi.Input[_builtins.str]:
        """
        Resource or resource path for which IAM policy information will be bound. The resource path may be specified in a few different [formats](https://www.vaultproject.io/docs/secrets/gcp/index.html#bindings).
        """
        return pulumi.get(self, "resource")

    @resource.setter
    def resource(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource", value)

    @_builtins.property
    @pulumi.getter
    def roles(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        List of [GCP IAM roles](https://cloud.google.com/iam/docs/understanding-roles) for the resource.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "roles", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SyncAssociationMetadata',
]

@pulumi.output_type
class SyncAssociationMetadata(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "subKey":
            suggest = "sub_key"
        elif key == "syncStatus":
            suggest = "sync_status"
        elif key == "updatedAt":
            suggest = "updated_at"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SyncAssociationMetadata. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SyncAssociationMetadata.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SyncAssociationMetadata.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 sub_key: Optional[_builtins.str] = None,
                 sync_status: Optional[_builtins.str] = None,
                 updated_at: Optional[_builtins.str] = None):
        """
        :param _builtins.str sub_key: Subkey of the associated secret.
        :param _builtins.str sync_status: A map of sync statuses for each subkey of the associated secret
               (for ex. `{kv_624bea/aws-token/dev: "SYNCED", kv_624bea/aws-token/prod: "SYNCED"}`).
        :param _builtins.str updated_at: A map of duration strings specifying when each subkey of the associated
               secret was last updated.
               (for ex.
               `{kv_624bea/aws-token/dev: "2024-03-21T12:42:02.558533-07:00",
               kv_624bea/aws-token/prod: "2024-03-21T12:42:02.558533-07:00"}`).
        """
        if sub_key is not None:
            pulumi.set(__self__, "sub_key", sub_key)
        if sync_status is not None:
            pulumi.set(__self__, "sync_status", sync_status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="subKey")
    def sub_key(self) -> Optional[_builtins.str]:
        """
        Subkey of the associated secret.
        """
        return pulumi.get(self, "sub_key")

    @_builtins.property
    @pulumi.getter(name="syncStatus")
    def sync_status(self) -> Optional[_builtins.str]:
        """
        A map of sync statuses for each subkey of the associated secret
        (for ex. `{kv_624bea/aws-token/dev: "SYNCED", kv_624bea/aws-token/prod: "SYNCED"}`).
        """
        return pulumi.get(self, "sync_status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[_builtins.str]:
        """
        A map of duration strings specifying when each subkey of the associated
        secret was last updated.
        (for ex.
        `{kv_624bea/aws-token/dev: "2024-03-21T12:42:02.558533-07:00",
        kv_624bea/aws-token/prod: "2024-03-21T12:42:02.558533-07:00"}`).
        """
        return pulumi.get(self, "updated_at")


